NuRadioReco.modules package
===========================

Subpackages
-----------

.. toctree::

    NuRadioReco.modules.custom
    NuRadioReco.modules.io

Submodules
----------

NuRadioReco.modules.channelBandPassFilter module
------------------------------------------------

.. automodule:: NuRadioReco.modules.channelBandPassFilter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelFirstPulseSampleWindow module
--------------------------------------------------------

.. automodule:: NuRadioReco.modules.channelFirstPulseSampleWindow
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelLengthAdjuster module
------------------------------------------------

.. automodule:: NuRadioReco.modules.channelLengthAdjuster
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelResampler module
-------------------------------------------

.. automodule:: NuRadioReco.modules.channelResampler
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelSignalReconstructor module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.channelSignalReconstructor
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelStopFilter module
--------------------------------------------

.. automodule:: NuRadioReco.modules.channelStopFilter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelTemplateCorrelation module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.channelTemplateCorrelation
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.channelTimeWindow module
--------------------------------------------

.. automodule:: NuRadioReco.modules.channelTimeWindow
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.correlationDirectionFitter module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.correlationDirectionFitter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.efieldToVoltageConverter module
---------------------------------------------------

.. automodule:: NuRadioReco.modules.efieldToVoltageConverter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.hardwareResponseIncorporator module
-------------------------------------------------------

.. automodule:: NuRadioReco.modules.hardwareResponseIncorporator
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.stationBandPassFilter module
------------------------------------------------

.. automodule:: NuRadioReco.modules.stationBandPassFilter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.stationPolarizationReconstructor module
-----------------------------------------------------------

.. automodule:: NuRadioReco.modules.stationPolarizationReconstructor
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.stationResampler module
-------------------------------------------

.. automodule:: NuRadioReco.modules.stationResampler
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.stationSignalReconstructor module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.stationSignalReconstructor
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.templateDirectionFitter module
--------------------------------------------------

.. automodule:: NuRadioReco.modules.templateDirectionFitter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.triggerSimulator module
-------------------------------------------

.. automodule:: NuRadioReco.modules.triggerSimulator
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.voltageToAnalyticEfieldConverter module
-----------------------------------------------------------

.. automodule:: NuRadioReco.modules.voltageToAnalyticEfieldConverter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.voltageToEfieldConverter module
---------------------------------------------------

.. automodule:: NuRadioReco.modules.voltageToEfieldConverter
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.modules
    :members:
    :undoc-members:
    :show-inheritance:
